/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |              (DATASET 0001: FACILITY DIRECTOR INTERVIEW)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02691-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE yearcomp  -3='(-3) MISSING' ;
  VALUE month1ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year1fff  -3='(-3) MISSING' ;
  VALUE month2ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year2fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE month3ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year3fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE month4ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year4fff  -3='(-3) MISSING' ;
  VALUE month5ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE year5fff  -3='(-3) MISSING' ;
  VALUE change    1='(1) Yes' 2='(2) No' ;
  VALUE owner     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE admin     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE reorg     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othchang  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE numchang  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE oveffect  -3='(-3) MISSING' 1='(1) Major alterations in almost every aspect'
                  2='(2) Significant changes in at least one aspe'
                  3='(3) Minor changes only' 4='(4) No effect' ;
  VALUE effectiv  -3='(-3) MISSING' 1='(1) Improved clinical effectiveness'
                  2='(2) Reduced clinical effectiveness' 3='(3) No change' ;
  VALUE yearend   -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE revenue   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE pubrev    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE pubrev2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE privrev   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE privrevf  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE pubins    -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE pubins2f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE npayhlf   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE npayhlff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE outpat    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hour24ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE othprog   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE fulltime  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff1ff  1='(1) Yes' 2='(2) No' ;
  VALUE left1fff  -3='(-3) MISSING' ;
  VALUE number1f  -3='(-3) MISSING' ;
  VALUE hours1ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE wage1fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefitf  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff2ff  1='(1) Yes' 2='(2) No' ;
  VALUE left2fff  -3='(-3) MISSING' ;
  VALUE number2f  -3='(-3) MISSING' ;
  VALUE hours2ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' ;
  VALUE wage2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi0f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff3ff  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE left3fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number3f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours3ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage3fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi1f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff4ff  1='(1) Yes' 2='(2) No' ;
  VALUE left4fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number4f  -3='(-3) MISSING' ;
  VALUE hours4ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage4fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE benefi2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff5ff  1='(1) Yes' 2='(2) No' ;
  VALUE left5fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number5f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours5ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage5fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE benefi3f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff6ff  1='(1) Yes' 2='(2) No' ;
  VALUE left6fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number6f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours6ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE wage6fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE benefi4f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE staff7ff  1='(1) Yes' 2='(2) No' ;
  VALUE left7fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number7f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours7ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage7fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi5f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff8ff  1='(1) Yes' 2='(2) No' ;
  VALUE left8fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number8f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours8ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage8fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi6f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff9ff  1='(1) Yes' 2='(2) No' ;
  VALUE left9fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number9f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours9ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage9fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE benefi7f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff10f  1='(1) Yes' 2='(2) No' ;
  VALUE left10ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE number0f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours10f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage10ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi8f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff11f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE left11ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE numbe10f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours11f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage11ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benefi9f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff12f  1='(1) Yes' 2='(2) No' ;
  VALUE left12ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE numbe11f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE hours12f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE wage12ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benef10f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE staff13f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE left13ff  -3='(-3) MISSING' ;
  VALUE numbe12f  -3='(-3) MISSING' ;
  VALUE hours13f  -3='(-3) MISSING' ;
  VALUE wage13ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE benef11f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' ;
  VALUE volunt    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE vhours    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE vwage     -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE ownface   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE value     -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE value2ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE rent      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE rent2fff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE utility   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE utilityf  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE supply    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE supply2f  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Month' 2='(2) Year' ;
  VALUE equip     -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE ovhead    -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE othcost   -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE patients  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE finknow   -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Extensively based on records'
                  2='(2) Somewhat based on records' 3='(3) Based on estimate' ;
  VALUE datayr    -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) 1990' 2='(2) 1993' ;
  VALUE datadif   -3='(-3) MISSING' 1='(1) All financial information about the same'
                  2='(2) 1993 figures would be higher'
                  3='(3) 1993 figures would be lower' 4='(4) Other (SPECIFY)' ;
  VALUE percdiff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' ;
  VALUE statmnt   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE copyst    -3='(-3) MISSING' 1='(1) Yes, report attached'
                  2='(2) Yes, report to be mailed'
                  3='(3) No, not specific enough to be useful'
                  4='(4) No, confidential' 5='(5) No, other reasons (SPECIFY)' ;
  VALUE partic    -3='(-3) MISSING' 1='(1) A great extent' 2='(2) A moderate extent'
                  3='(3) A small extent' ;
  VALUE abstin    -3='(-3) MISSING' 1='(1) A great extent' 2='(2) A moderate extent'
                  3='(3) A small extent' 4='(4) No extent' ;
  VALUE follow    -3='(-3) MISSING' 1='(1) A great extent' 2='(2) A moderate extent'
                  3='(3) A small extent' 4='(4) No extent' ;
  VALUE phone     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE mail      -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE intview   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE othmeth   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE datacolf  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE dataco0f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE dataco1f  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE report    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE copyrep   -3='(-3) MISSING' 1='(1) Yes, report attached'
                  2='(2) Yes, report to be mailed'
                  3='(3) No, not specific enough to be useful'
                  4='(4) No, confidential' 5='(5) No, other reasons (SPECIFY)' ;
  VALUE alumni    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE jcano     -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE carf      -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE mode      1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient Methadone Maintenance'
                  4='(4) Outpatient Drug-Free' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=373;
INPUT
        CASEID 1-2              FAC_ID 3-6              YEARCOMP 7-8
        MONTH1 9-10             YEAR1 11-12             MONTH2 13-14
        YEAR2 15-16             MONTH3 17-18            YEAR3 19-20
        MONTH4 21-22            YEAR4 23-24             MONTH5 25-26
        YEAR5 27-28             CHANGE 29               OWNER 30-31
        ADMIN 32-33             REORG 34-35             OTHCHANG 36-37
        NUMCHANG 38-39          OVEFFECT 40-41          EFFECTIV 42-43
        YEAREND 44-45           REVENUE 46-52           PUBREV 53-54
        PUBREV2 55-57           PRIVREV 58-59           PRIVREV2 60-61
        PUBINS 62-63            PUBINS2 64-65           NPAYHLF 66-67
        NPAYHLF2 68-70          OUTPAT 71-73            HOUR24 74-77
        OTHPROG 78-81           FULLTIME 82-85          STAFF1 86
        LEFT1 87-88             NUMBER1 89-90           HOURS1 91-94
        WAGE1 95-96             BENEFIT1 97-98          STAFF2 99
        LEFT2 100-101           NUMBER2 102-103         HOURS2 104-107
        WAGE2 108-109           BENEFIT2 110-111        STAFF3 112-113
        LEFT3 114-115           NUMBER3 116-117         HOURS3 118-122
        WAGE3 123-124           BENEFIT3 125-126        STAFF4 127
        LEFT4 128-129           NUMBER4 130-131         HOURS4 132-136
        WAGE4 137-138           BENEFIT4 139-140        STAFF5 141
        LEFT5 142-143           NUMBER5 144-145         HOURS5 146-150
        WAGE5 151-152           BENEFIT5 153-154        STAFF6 155
        LEFT6 156-157           NUMBER6 158-159         HOURS6 160-164
        WAGE6 165-166           BENEFIT6 167-168        STAFF7 169
        LEFT7 170-171           NUMBER7 172-173         HOURS7 174-178
        WAGE7 179-180           BENEFIT7 181-182        STAFF8 183
        LEFT8 184-185           NUMBER8 186-187         HOURS8 188-192
        WAGE8 193-194           BENEFIT8 195-196        STAFF9 197
        LEFT9 198-199           NUMBER9 200-201         HOURS9 202-206
        WAGE9 207-208           BENEFIT9 209-210        STAFF10 211
        LEFT10 212-213          NUMBER10 214-215        HOURS10 216-220
        WAGE10 221-222          BENEFI10 223-224        STAFF11 225-226
        LEFT11 227-228          NUMBER11 229-230        HOURS11 231-235
        WAGE11 236-237          BENEFI11 238-239        STAFF12 240
        LEFT12 241-242          NUMBER12 243-244        HOURS12 245-249
        WAGE12 250-251          BENEFI12 252-253        STAFF13 254-255
        LEFT13 256-257          NUMBER13 258-259        HOURS13 260-264
        WAGE13 265-266          BENEFI13 267-268        VOLUNT 269-270
        VHOURS 271-275          VWAGE 276-277           OWNFACE 278-279
        VALUE 280-286           VALUE2 287-288          RENT 289-293
        RENT2 294-295           UTILITY 296-301         UTILITY2 302-303
        SUPPLY 304-309          SUPPLY2 310-311         EQUIP 312-317
        OVHEAD 318-323          OTHCOST 324-325         PATIENTS 326-329
        FINKNOW 330-331         DATAYR 332-333          DATADIF 334-335
        PERCDIFF 336-338        STATMNT 339-340         COPYST 341-342
        PARTIC 343-344          ABSTIN 345-346          FOLLOW 347-348
        PHONE 349-350           MAIL 351-352            INTVIEW 353-354
        OTHMETH 355-356         DATACOL1 357-358        DATACOL2 359-360
        DATACOL3 361-362        REPORT 363-364          COPYREP 365-366
        ALUMNI 367-368          JCANO 369-370           CARF 371-372
        MODE 373                ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   FAC_ID  = 'FACILITY ID'
   YEARCOMP= 'COMPLETION -- YEAR'
   MONTH1  = 'Q1 MONTH'
   YEAR1   = 'Q1 YEAR'
   MONTH2  = 'Q2 MONTH'
   YEAR2   = 'Q2 YEAR'
   MONTH3  = 'Q3 MONTH'
   YEAR3   = 'Q3 YEAR'
   MONTH4  = 'Q4 MONTH'
   YEAR4   = 'Q4 YEAR'
   MONTH5  = 'Q5 MONTH'
   YEAR5   = 'Q5 YEAR'
   CHANGE  = 'Q2 CHANGE OWNERSHIP'
   OWNER   = 'Q2A1 CHANGE IN PRIVATE OWNERSHIP'
   ADMIN   = 'Q2A1 CHANGE IN PRIVATE ADMINISTRATION'
   REORG   = 'Q2A1 REORGANIZATION OF PUBLIC AGENCY, TO'
   OTHCHANG= 'Q2A1 OTHER'
   NUMCHANG= 'Q2B TIMES CHANGE OCCURRED'
   OVEFFECT= 'Q2C THE OVERALL EFFECT'
   EFFECTIV= 'Q2D CHANGES ON EFFECTIVENESS'
   YEAREND = 'Q3A YEAR ENDING DATE'
   REVENUE = 'Q3B TOTAL REVENUES'
   PUBREV  = 'Q3C PUBLIC AGENCIES'
   PUBREV2 = 'Q3D PERCENT OF REVENUE'
   PRIVREV = 'Q3E PRIVATE INSURANCE'
   PRIVREV2= 'Q3F PERCENT COVERD PRIVATE'
   PUBINS  = 'Q3G COVERD BY PUBLIC'
   PUBINS2 = 'Q3H PUBLIC INSURANCE'
   NPAYHLF = 'Q3I UNABLE TO PAY EVEN HALF'
   NPAYHLF2= 'Q3J UNABLE TO PAY HALF'
   OUTPAT  = 'Q4A CHARGE OUTPATIENT'
   HOUR24  = 'Q4B PER 24-HOUR STAY'
   OTHPROG = 'Q4C PER OTHER PROGRAM'
   FULLTIME= 'Q5A HOURS AMOUNT OF ANNUAL HOURS CONSIDE'
   STAFF1  = 'Q5BA PAID STAFF 12 MN'
   LEFT1   = 'Q5CA NUM WHO LEFT'
   NUMBER1 = 'Q5DA NUM AT END'
   HOURS1  = 'Q5EA NUM OF HR WORKED'
   WAGE1   = 'Q5FA AVRG HRLY RATE $'
   BENEFIT1= 'Q5GA FRINGE BENEFIT %'
   STAFF2  = 'Q5BB PAID STAFF 12 MN'
   LEFT2   = 'Q5CB NUM WHO LEFT'
   NUMBER2 = 'Q5DB NUM AT END'
   HOURS2  = 'Q5EB NUM OF HR WORKED'
   WAGE2   = 'Q5FB AVRG HRLY RATE $'
   BENEFIT2= 'Q5GB FRINGE BENEFIT %'
   STAFF3  = 'Q5BC PAID STAFF 12 MN'
   LEFT3   = 'Q5CC NUM WHO LEFT'
   NUMBER3 = 'Q5DC NUM AT END'
   HOURS3  = 'Q5EC NUM OF HR WORKED'
   WAGE3   = 'Q5FC AVRG HRLY RATE $'
   BENEFIT3= 'Q5GC FRINGE BENEFIT %'
   STAFF4  = 'Q5BD PAID STAFF 12 MN'
   LEFT4   = 'Q5CD NUM WHO LEFT'
   NUMBER4 = 'Q5DD NUM AT END'
   HOURS4  = 'Q5ED NUM OF HR WORKED'
   WAGE4   = 'Q5FD AVRG HRLY RATE $'
   BENEFIT4= 'Q5GD FRINGE BENEFIT %'
   STAFF5  = 'Q5BE PAID STAFF 12 MN'
   LEFT5   = 'Q5CE NUM WHO LEFT'
   NUMBER5 = 'Q5DE NUM AT END'
   HOURS5  = 'Q5EE NUM OF HR WORKED'
   WAGE5   = 'Q5FE AVRG HRLY RATE $'
   BENEFIT5= 'Q5GE FRINGE BENEFIT %'
   STAFF6  = 'Q5BF PAID STAFF 12 MN'
   LEFT6   = 'Q5CF NUM WHO LEFT'
   NUMBER6 = 'Q5DF NUM AT END'
   HOURS6  = 'Q5EF NUM OF HR WORKED'
   WAGE6   = 'Q5FF AVRG HRLY RATE $'
   BENEFIT6= 'Q5GF FRINGE BENEFIT %'
   STAFF7  = 'Q5BG PAID STAFF 12 MN'
   LEFT7   = 'Q5CG NUM WHO LEFT'
   NUMBER7 = 'Q5DG NUM AT END'
   HOURS7  = 'Q5EG NUM OF HR WORKED'
   WAGE7   = 'Q5FG AVRG HRLY RATE $'
   BENEFIT7= 'Q5GG FRINGE BENEFIT %'
   STAFF8  = 'Q5BH PAID STAFF 12 MN'
   LEFT8   = 'Q5CH NUM WHO LEFT'
   NUMBER8 = 'Q5DH NUM AT END'
   HOURS8  = 'Q5EH NUM OF HR WORKED'
   WAGE8   = 'Q5FH AVRG HRLY RATE $'
   BENEFIT8= 'Q5GH FRINGE BENEFIT %'
   STAFF9  = 'Q5BI PAID STAFF 12 MN'
   LEFT9   = 'Q5CI NUM WHO LEFT'
   NUMBER9 = 'Q5DI NUM AT END'
   HOURS9  = 'Q5EI NUM OF HR WORKED'
   WAGE9   = 'Q5FI AVRG HRLY RATE $'
   BENEFIT9= 'Q5GI FRINGE BENEFIT %'
   STAFF10 = 'Q5BJ PAID STAFF 12 MN'
   LEFT10  = 'Q5CJ NUM WHO LEFT'
   NUMBER10= 'Q5DJ NUM AT END'
   HOURS10 = 'Q5EJ NUM OF HR WORKED'
   WAGE10  = 'Q5FJ AVRG HRLY RATE $'
   BENEFI10= 'Q5GJ FRINGE BENEFIT %'
   STAFF11 = 'Q5BK PAID STAFF 12 MN'
   LEFT11  = 'Q5CK NUM WHO LEFT'
   NUMBER11= 'Q5DK NUM AT END'
   HOURS11 = 'Q5EK NUM OF HR WORKED'
   WAGE11  = 'Q5FK AVRG HRLY RATE $'
   BENEFI11= 'Q5GK FRINGE BENEFIT %'
   STAFF12 = 'Q5BL PAID STAFF 12 MN'
   LEFT12  = 'Q5CL NUM WHO LEFT'
   NUMBER12= 'Q5DL NUM AT END'
   HOURS12 = 'Q5EL NUM OF HR WORKED'
   WAGE12  = 'Q5FL AVRG HRLY RATE $'
   BENEFI12= 'Q5GL FRINGE BENEFIT %'
   STAFF13 = 'Q5BM PAID STAFF 12 MN'
   LEFT13  = 'Q5CM NUM WHO LEFT'
   NUMBER13= 'Q5DM NUM AT END'
   HOURS13 = 'Q5EM NUM OF HR WORKED'
   WAGE13  = 'Q5FM AVRG HRLY RATE $'
   BENEFI13= 'Q5GM FRINGE BENEFIT %'
   VOLUNT  = 'VOLUNTEER SUPPORT'
   VHOURS  = 'Q6A VOLUNTEER HOURS'
   VWAGE   = 'Q6B HOURLY RATE'
   OWNFACE = 'Q7 PROGRAM OWN FACILITY'
   VALUE   = 'Q7A SPACE RENTAL VALUE'
   VALUE2  = 'Q7A MONTH OR YEAR'
   RENT    = 'Q8 LEASE/RENTAL COST'
   RENT2   = 'Q8 MONTH OR YEAR'
   UTILITY = 'Q9 UTILITIES,TAXES'
   UTILITY2= 'Q9 MONTH OR YEAR'
   SUPPLY  = 'Q10 SUPPLIES,SERVICES'
   SUPPLY2 = 'Q10 MONTH OR YEAR'
   EQUIP   = 'Q11 AMORTIZED EQUIPMENT'
   OVHEAD  = 'Q12 ADDITIONAL OVERHEAD'
   OTHCOST = 'Q13 ADDITIONAL COST NOT COVERED'
   PATIENTS= 'Q14 NUM OF PATIENTS'
   FINKNOW = 'Q15 BASED ON KNOWLEDGE'
   DATAYR  = 'Q16 DATA 1990/1993'
   DATADIF = 'Q16A 1993 DIFF 1990'
   PERCDIFF= 'Q16A (SPECIFY:__%)'
   STATMNT = 'Q17 FINANCIAL STATEMENT'
   COPYST  = 'Q17A COPY OF FINANCIAL'
   PARTIC  = 'Q18 CLIENTS PARTICIPATE'
   ABSTIN  = 'Q19 ABSTINENCE FROM ALCOHOL'
   FOLLOW  = 'Q20 OBTAIN FOLLOW-UP'
   PHONE   = 'Q20A TELEPHONE'
   MAIL    = 'Q20A MAIL'
   INTVIEW = 'Q20A PERSONAL INTERVIEW'
   OTHMETH = 'Q20A OTHER'
   DATACOL1= 'Q20B PROGRAM STAFF'
   DATACOL2= 'Q20B OTHER STAFF IN PROGRAM'
   DATACOL3= 'Q20B OUTSIDE CONSULTANT/CONTRACTOR/RESEA'
   REPORT  = 'Q20C REPORTS AVAILABLE'
   COPYREP = 'Q20D COPY OF THE REPORT'
   ALUMNI  = 'Q21 ALUMNI GROUPS'
   JCANO   = 'Q22JCAHO YES/NO'
   CARF    = 'Q22CARF YES/NO'
   MODE    = 'DOMINANT TREATMENT TYPE IN FAC'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (FAC_ID <= -1) THEN FAC_ID = .;
   IF (YEARCOMP <= -1) THEN YEARCOMP = .;
   IF (MONTH1 <= -1) THEN MONTH1 = .;
   IF (YEAR1 <= -1) THEN YEAR1 = .;
   IF (MONTH2 <= -1) THEN MONTH2 = .;
   IF (YEAR2 <= -1) THEN YEAR2 = .;
   IF (MONTH3 <= -1) THEN MONTH3 = .;
   IF (YEAR3 <= -1) THEN YEAR3 = .;
   IF (MONTH4 <= -1) THEN MONTH4 = .;
   IF (YEAR4 <= -1) THEN YEAR4 = .;
   IF (MONTH5 <= -1) THEN MONTH5 = .;
   IF (YEAR5 <= -1) THEN YEAR5 = .;
   IF (CHANGE <= -1) THEN CHANGE = .;
   IF (OWNER <= -1) THEN OWNER = .;
   IF (ADMIN <= -1) THEN ADMIN = .;
   IF (REORG <= -1) THEN REORG = .;
   IF (OTHCHANG <= -1) THEN OTHCHANG = .;
   IF (NUMCHANG <= -1) THEN NUMCHANG = .;
   IF (OVEFFECT <= -1) THEN OVEFFECT = .;
   IF (EFFECTIV <= -1) THEN EFFECTIV = .;
   IF (YEAREND <= -1) THEN YEAREND = .;
   IF (REVENUE <= -1) THEN REVENUE = .;
   IF (PUBREV <= -1) THEN PUBREV = .;
   IF (PUBREV2 <= -1) THEN PUBREV2 = .;
   IF (PRIVREV <= -1) THEN PRIVREV = .;
   IF (PRIVREV2 <= -1) THEN PRIVREV2 = .;
   IF (PUBINS <= -1) THEN PUBINS = .;
   IF (PUBINS2 <= -1) THEN PUBINS2 = .;
   IF (NPAYHLF <= -1) THEN NPAYHLF = .;
   IF (NPAYHLF2 <= -1) THEN NPAYHLF2 = .;
   IF (OUTPAT <= -1) THEN OUTPAT = .;
   IF (HOUR24 <= -1) THEN HOUR24 = .;
   IF (OTHPROG <= -1) THEN OTHPROG = .;
   IF (FULLTIME <= -1) THEN FULLTIME = .;
   IF (STAFF1 <= -1) THEN STAFF1 = .;
   IF (LEFT1 <= -1) THEN LEFT1 = .;
   IF (NUMBER1 <= -1) THEN NUMBER1 = .;
   IF (HOURS1 <= -1) THEN HOURS1 = .;
   IF (WAGE1 <= -1) THEN WAGE1 = .;
   IF (BENEFIT1 <= -1) THEN BENEFIT1 = .;
   IF (STAFF2 <= -1) THEN STAFF2 = .;
   IF (LEFT2 <= -1) THEN LEFT2 = .;
   IF (NUMBER2 <= -1) THEN NUMBER2 = .;
   IF (HOURS2 <= -1) THEN HOURS2 = .;
   IF (WAGE2 <= -1) THEN WAGE2 = .;
   IF (BENEFIT2 <= -1) THEN BENEFIT2 = .;
   IF (STAFF3 <= -1) THEN STAFF3 = .;
   IF (LEFT3 <= -1) THEN LEFT3 = .;
   IF (NUMBER3 <= -1) THEN NUMBER3 = .;
   IF (HOURS3 <= -1) THEN HOURS3 = .;
   IF (WAGE3 <= -1) THEN WAGE3 = .;
   IF (BENEFIT3 <= -1) THEN BENEFIT3 = .;
   IF (STAFF4 <= -1) THEN STAFF4 = .;
   IF (LEFT4 <= -1) THEN LEFT4 = .;
   IF (NUMBER4 <= -1) THEN NUMBER4 = .;
   IF (HOURS4 <= -1) THEN HOURS4 = .;
   IF (WAGE4 <= -1) THEN WAGE4 = .;
   IF (BENEFIT4 <= -1) THEN BENEFIT4 = .;
   IF (STAFF5 <= -1) THEN STAFF5 = .;
   IF (LEFT5 <= -1) THEN LEFT5 = .;
   IF (NUMBER5 <= -1) THEN NUMBER5 = .;
   IF (HOURS5 <= -1) THEN HOURS5 = .;
   IF (WAGE5 <= -1) THEN WAGE5 = .;
   IF (BENEFIT5 <= -1) THEN BENEFIT5 = .;
   IF (STAFF6 <= -1) THEN STAFF6 = .;
   IF (LEFT6 <= -1) THEN LEFT6 = .;
   IF (NUMBER6 <= -1) THEN NUMBER6 = .;
   IF (HOURS6 <= -1) THEN HOURS6 = .;
   IF (WAGE6 <= -1) THEN WAGE6 = .;
   IF (BENEFIT6 <= -1) THEN BENEFIT6 = .;
   IF (STAFF7 <= -1) THEN STAFF7 = .;
   IF (LEFT7 <= -1) THEN LEFT7 = .;
   IF (NUMBER7 <= -1) THEN NUMBER7 = .;
   IF (HOURS7 <= -1) THEN HOURS7 = .;
   IF (WAGE7 <= -1) THEN WAGE7 = .;
   IF (BENEFIT7 <= -1) THEN BENEFIT7 = .;
   IF (STAFF8 <= -1) THEN STAFF8 = .;
   IF (LEFT8 <= -1) THEN LEFT8 = .;
   IF (NUMBER8 <= -1) THEN NUMBER8 = .;
   IF (HOURS8 <= -1) THEN HOURS8 = .;
   IF (WAGE8 <= -1) THEN WAGE8 = .;
   IF (BENEFIT8 <= -1) THEN BENEFIT8 = .;
   IF (STAFF9 <= -1) THEN STAFF9 = .;
   IF (LEFT9 <= -1) THEN LEFT9 = .;
   IF (NUMBER9 <= -1) THEN NUMBER9 = .;
   IF (HOURS9 <= -1) THEN HOURS9 = .;
   IF (WAGE9 <= -1) THEN WAGE9 = .;
   IF (BENEFIT9 <= -1) THEN BENEFIT9 = .;
   IF (STAFF10 <= -1) THEN STAFF10 = .;
   IF (LEFT10 <= -1) THEN LEFT10 = .;
   IF (NUMBER10 <= -1) THEN NUMBER10 = .;
   IF (HOURS10 <= -1) THEN HOURS10 = .;
   IF (WAGE10 <= -1) THEN WAGE10 = .;
   IF (BENEFI10 <= -1) THEN BENEFI10 = .;
   IF (STAFF11 <= -1) THEN STAFF11 = .;
   IF (LEFT11 <= -1) THEN LEFT11 = .;
   IF (NUMBER11 <= -1) THEN NUMBER11 = .;
   IF (HOURS11 <= -1) THEN HOURS11 = .;
   IF (WAGE11 <= -1) THEN WAGE11 = .;
   IF (BENEFI11 <= -1) THEN BENEFI11 = .;
   IF (STAFF12 <= -1) THEN STAFF12 = .;
   IF (LEFT12 <= -1) THEN LEFT12 = .;
   IF (NUMBER12 <= -1) THEN NUMBER12 = .;
   IF (HOURS12 <= -1) THEN HOURS12 = .;
   IF (WAGE12 <= -1) THEN WAGE12 = .;
   IF (BENEFI12 <= -1) THEN BENEFI12 = .;
   IF (STAFF13 <= -1) THEN STAFF13 = .;
   IF (LEFT13 <= -1) THEN LEFT13 = .;
   IF (NUMBER13 <= -1) THEN NUMBER13 = .;
   IF (HOURS13 <= -1) THEN HOURS13 = .;
   IF (WAGE13 <= -1) THEN WAGE13 = .;
   IF (BENEFI13 <= -1) THEN BENEFI13 = .;
   IF (VOLUNT <= -1) THEN VOLUNT = .;
   IF (VHOURS <= -1) THEN VHOURS = .;
   IF (VWAGE <= -1) THEN VWAGE = .;
   IF (OWNFACE <= -1) THEN OWNFACE = .;
   IF (VALUE <= -1) THEN VALUE = .;
   IF (VALUE2 <= -1) THEN VALUE2 = .;
   IF (RENT <= -1) THEN RENT = .;
   IF (RENT2 <= -1) THEN RENT2 = .;
   IF (UTILITY <= -1) THEN UTILITY = .;
   IF (UTILITY2 <= -1) THEN UTILITY2 = .;
   IF (SUPPLY <= -1) THEN SUPPLY = .;
   IF (SUPPLY2 <= -1) THEN SUPPLY2 = .;
   IF (EQUIP <= -1) THEN EQUIP = .;
   IF (OVHEAD <= -1) THEN OVHEAD = .;
   IF (OTHCOST <= -1) THEN OTHCOST = .;
   IF (PATIENTS <= -1) THEN PATIENTS = .;
   IF (FINKNOW <= -1) THEN FINKNOW = .;
   IF (DATAYR <= -1) THEN DATAYR = .;
   IF (DATADIF <= -1) THEN DATADIF = .;
   IF (PERCDIFF <= -1) THEN PERCDIFF = .;
   IF (STATMNT <= -1) THEN STATMNT = .;
   IF (COPYST <= -1) THEN COPYST = .;
   IF (PARTIC <= -1) THEN PARTIC = .;
   IF (ABSTIN <= -1) THEN ABSTIN = .;
   IF (FOLLOW <= -1) THEN FOLLOW = .;
   IF (PHONE <= -1) THEN PHONE = .;
   IF (MAIL <= -1) THEN MAIL = .;
   IF (INTVIEW <= -1) THEN INTVIEW = .;
   IF (OTHMETH <= -1) THEN OTHMETH = .;
   IF (DATACOL1 <= -1) THEN DATACOL1 = .;
   IF (DATACOL2 <= -1) THEN DATACOL2 = .;
   IF (DATACOL3 <= -1) THEN DATACOL3 = .;
   IF (REPORT <= -1) THEN REPORT = .;
   IF (COPYREP <= -1) THEN COPYREP = .;
   IF (ALUMNI <= -1) THEN ALUMNI = .;
   IF (JCANO <= -1) THEN JCANO = .;
   IF (CARF <= -1) THEN CARF = .;
   IF (MODE <= -1) THEN MODE = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT YEARCOMP yearcomp. MONTH1 month1ff. YEAR1 year1fff.
         MONTH2 month2ff. YEAR2 year2fff. MONTH3 month3ff.
         YEAR3 year3fff. MONTH4 month4ff. YEAR4 year4fff.
         MONTH5 month5ff. YEAR5 year5fff. CHANGE change.
         OWNER owner. ADMIN admin. REORG reorg.
         OTHCHANG othchang. NUMCHANG numchang. OVEFFECT oveffect.
         EFFECTIV effectiv. YEAREND yearend. REVENUE revenue.
         PUBREV pubrev. PUBREV2 pubrev2f. PRIVREV privrev.
         PRIVREV2 privrevf. PUBINS pubins. PUBINS2 pubins2f.
         NPAYHLF npayhlf. NPAYHLF2 npayhlff. OUTPAT outpat.
         HOUR24 hour24ff. OTHPROG othprog. FULLTIME fulltime.
         STAFF1 staff1ff. LEFT1 left1fff. NUMBER1 number1f.
         HOURS1 hours1ff. WAGE1 wage1fff. BENEFIT1 benefitf.
         STAFF2 staff2ff. LEFT2 left2fff. NUMBER2 number2f.
         HOURS2 hours2ff. WAGE2 wage2fff. BENEFIT2 benefi0f.
         STAFF3 staff3ff. LEFT3 left3fff. NUMBER3 number3f.
         HOURS3 hours3ff. WAGE3 wage3fff. BENEFIT3 benefi1f.
         STAFF4 staff4ff. LEFT4 left4fff. NUMBER4 number4f.
         HOURS4 hours4ff. WAGE4 wage4fff. BENEFIT4 benefi2f.
         STAFF5 staff5ff. LEFT5 left5fff. NUMBER5 number5f.
         HOURS5 hours5ff. WAGE5 wage5fff. BENEFIT5 benefi3f.
         STAFF6 staff6ff. LEFT6 left6fff. NUMBER6 number6f.
         HOURS6 hours6ff. WAGE6 wage6fff. BENEFIT6 benefi4f.
         STAFF7 staff7ff. LEFT7 left7fff. NUMBER7 number7f.
         HOURS7 hours7ff. WAGE7 wage7fff. BENEFIT7 benefi5f.
         STAFF8 staff8ff. LEFT8 left8fff. NUMBER8 number8f.
         HOURS8 hours8ff. WAGE8 wage8fff. BENEFIT8 benefi6f.
         STAFF9 staff9ff. LEFT9 left9fff. NUMBER9 number9f.
         HOURS9 hours9ff. WAGE9 wage9fff. BENEFIT9 benefi7f.
         STAFF10 staff10f. LEFT10 left10ff. NUMBER10 number0f.
         HOURS10 hours10f. WAGE10 wage10ff. BENEFI10 benefi8f.
         STAFF11 staff11f. LEFT11 left11ff. NUMBER11 numbe10f.
         HOURS11 hours11f. WAGE11 wage11ff. BENEFI11 benefi9f.
         STAFF12 staff12f. LEFT12 left12ff. NUMBER12 numbe11f.
         HOURS12 hours12f. WAGE12 wage12ff. BENEFI12 benef10f.
         STAFF13 staff13f. LEFT13 left13ff. NUMBER13 numbe12f.
         HOURS13 hours13f. WAGE13 wage13ff. BENEFI13 benef11f.
         VOLUNT volunt. VHOURS vhours. VWAGE vwage.
         OWNFACE ownface. VALUE value. VALUE2 value2ff.
         RENT rent. RENT2 rent2fff. UTILITY utility.
         UTILITY2 utilityf. SUPPLY supply. SUPPLY2 supply2f.
         EQUIP equip. OVHEAD ovhead. OTHCOST othcost.
         PATIENTS patients. FINKNOW finknow. DATAYR datayr.
         DATADIF datadif. PERCDIFF percdiff. STATMNT statmnt.
         COPYST copyst. PARTIC partic. ABSTIN abstin.
         FOLLOW follow. PHONE phone. MAIL mail.
         INTVIEW intview. OTHMETH othmeth. DATACOL1 datacolf.
         DATACOL2 dataco0f. DATACOL3 dataco1f. REPORT report.
         COPYREP copyrep. ALUMNI alumni. JCANO jcano.
         CARF carf. MODE mode.  ;
*/

RUN ;
